# SPT: SPHERE Psychometrics Tools

R package for psychometrics modeling using Rasch Measurement Theory (RMT). This package focuses on cross-sectional RMT modeling, statistical inference, DIF analysis and causal inference. 

SPT uses utilities from various other software to function. Please cite these when using SPT:

  - R package ```vcrpart``` for Marginal Maximum Likelihood (MML) estimation of Rasch family models as mixed-effects ordinal regression models
  - R package ```PP``` for a posteriori person parameter estimation
  - ```JAGS``` and R packages ```rjags``` and ```dclone``` for MCMC estimation of bayesian models
  
The primary aim of SPT is to implement features of RMT that are currently unavailable in R, including model estimation with DIF parameters, iterative DIF detection methods and causal inference methods for RMT models.

**Please note that SPT is currently under active development and is thus incomplete and may contain bugs. Please check this repository regularly for updates and open an issue and/or submit a pull request if you encounter any problem.**

## Installation

Install dependencies and the ```devtools``` package required for installation:

```r
install.packages("vcrpart","rjags","dclone","PP","devtools")
```

Please note you also need to install [git](https://git-scm.com/) and [RTools](https://cran.r-project.org/bin/windows/Rtools/) to install SPT. In order to run bayesian models, please also install [JAGS](https://mcmc-jags.sourceforge.io/).

Then, install SPT:

```r
devtools::install_git("https://gitlab.univ-nantes.fr/choisy-c/spt.git")
```

### Upgrading

```r
# If SPT is currently loaded in your environment
detach("package:SPT",unload=T)
devtools::install_git("https://gitlab.univ-nantes.fr/choisy-c/spt.git")
```

## Author

[Corentin Choisy](https://www.univ-nantes.fr/corentin-choisy)

I am a PhD Student in Psychometrics, Biostatistics and Epidemiology for Inserm UMR 1246 SPHERE (methodS in Patient-centered outcomes and HEalth ResEarch) at Nantes University, France. I work on Rasch Measurement Theory, causal inference and non-invariance analyses in psychometrics applied to health research.

 - ORCID: [0009-0002-6988-3289](https://orcid.org/0009-0002-6988-3289)
 - HAL: [corentin-choisy](https://cv.hal.science/corentin-choisy)
 - Mastodon: [@corentinchoisy](https://mastodon.social/@corentinchoisy)

## Issues

If you encounter a problem or bug or want to request a feature, please create an issue using the service desk by sending an email to [gitlab-incoming+choisy-c-spt-30197-issue-@univ-nantes.fr](mailto:gitlab-incoming+choisy-c-spt-30197-issue-@univ-nantes.fr) 

Pull requests should also be submitted by this procedure.
 
## License

SPT is licensed under the [GNU Affero General Public License version 3](https://www.gnu.org/licenses/agpl-3.0.html)

![agpl3 logo](https://www.gnu.org/graphics/agplv3-with-text-162x68.png)

